# Permutation Importance

PHOTONAI conveniently integrates scikit-learns permutation importance function to get the permutation 
feature importances for the optimum pipe after optimization is finished.  

```python hl_lines="21"
{% include 'examples/advanced/feature_importance.py'%}
```